@@ -1,4 +1,4 @@
-from __future__ import division, with_statement
+from __future__ import division
 
 from datetime import datetime, timedelta
 
